@@ -372,8 +372,6 @@ class GP(Heuristics):
                 phenotype = self.representation.genotype_to_phenotype(self.grammar, ind.genotype)
                 conforms_min_depth = True if not min_init else (phenotype.gengy_distance_to_term >= min_init)
                 conforms_max_depth = True if not max_init else (phenotype.gengy_distance_to_term <= max_init)
-                if not (conforms_min_depth and conforms_max_depth):
-                    print(phenotype.gengy_distance_to_term)
                 return conforms_min_depth and conforms_max_depth
             
             conforms_depth = False
@@ -389,7 +387,7 @@ class GP(Heuristics):
             n_not_ramped = int(self.population_size / 2)
             n_ramped = self.population_size - n_not_ramped 
             pop_ramped = [
-                create_ind_w_restrictions(self.max_depth, min_init=self.min_init_depth, max_init=max((i % self.max_init_depth) + 1, self.grammar.get_min_tree_depth()))
+                create_ind_w_restrictions(self.max_depth, min_init=self.min_init_depth, max_init=max((i % self.max_init_depth) + 1, self.grammar.get_min_tree_depth(), (0 if not self.min_init_depth else self.min_init_depth)))
                 for i in range(n_ramped)
             ]
             pop_not_ramped = [
